Exception: ActiveHarness::Errors::GuardResponseError
- Defined in:
- lib/active_harness/core/errors.rb
Overview
Guard — raised when the guard model returns unparseable or schema-invalid JSON. Triggers the retry loop inside GuardRunner.
Guard — raised when the guard model returns unparseable or schema-invalid JSON. Triggers the retry loop inside GuardRunner.